# Perceptron_pypi
python package indexing for Perceptron implemetation

# How to use 

```python
pip install Perceptron-pypi-vishalbansal-1650
```
```python
## Initiate perceptron and fit it
model = Perceptron(eta=eta, epochs=epochs)
model.fit(x,y)
```
```python
## Prepare dataset
x,y = prepare_data(df)
```
```python
## Save model file
save_model(model,modelName)
```
```python
## Save plot
save_plot(df,plotName,model)
```


# URL for pypi

[Perceptron pypi page](https://pypi.org/project/Perceptron-pypi-vishalbansal-1650/)

# References 

[Python Documentation for pypi](https://packaging.python.org/tutorials/packaging-projects/)


[Offical docs for GitHub Actions](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)
